@@ -1,11 +1,12 @@
-import warnings
 import logging
-import numpy as np
+import warnings
 from dataclasses import dataclass
+from typing import Tuple
+
+import numpy as np
 from scipy.linalg import eig
 from scipy.optimize import fmin_bfgs
 from scipy.spatial.distance import pdist
-from sklearn.decomposition import PCA
 
 
 _required_opts = ['analytic', 'ntries']
@@ -93,10 +94,10 @@ def pilot(X, Y, featlabels=None, **kwargs):
     return out
 
 
-def adjust_rotation(Z: np.ndarray, Ybad: np.ndarray, theta=135):
+def adjust_rotation(Z: np.ndarray, Ybad: np.ndarray, theta: float = 135.0) -> Tuple[np.ndarray, np.ndarray]:
     cenroid_bad = np.mean(Z[Ybad], axis=0)[::-1]
     theta = np.radians(theta) - np.arctan2(*cenroid_bad)
     rot = np.array(((np.cos(theta), -np.sin(theta)),
                     (np.sin(theta), np.cos(theta))))
     Z_rot = np.dot(rot, Z.T)
-    return Z_rot.T
+    return Z_rot.T, rot
