@@ -3,6 +3,7 @@ import time
 import warnings
 from dataclasses import dataclass
 from itertools import repeat
+from math import ceil
 from multiprocessing import Pool, cpu_count
 from typing import List, Union
 
@@ -225,7 +226,7 @@ def trace_build(Z, Ybin, PI) -> FootprintOutput:
     if Ig.shape[0] < 3:
         raise TraceException
 
-    nn = max(min(np.ceil(sum(Ybin) / 20), 50), 3)
+    nn = max(min(ceil(sum(Ybin) / 20), 50), 3)
     eps = estimate_epsilon(Ig, nn)
     clustering = DBSCAN(eps=eps, min_samples=nn).fit(Ig)
 
